# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional, Union
from pydantic import BaseModel, StrictBool, StrictFloat, StrictInt, StrictStr

class InternalTransactionDataModel(BaseModel):
    """
    InternalTransactionDataModel
    """
    pcode: Optional[StrictStr] = None
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    request_amount: Optional[Union[StrictFloat, StrictInt]] = None
    additional_amount: Optional[Union[StrictFloat, StrictInt]] = None
    acquirer_fee: Optional[Union[StrictFloat, StrictInt]] = None
    refid: Optional[StrictInt] = None
    ref_itc: Optional[StrictStr] = None
    account2_id: Optional[StrictInt] = None
    country: Optional[StrictStr] = None
    currency: Optional[StrictStr] = None
    settlement_currency: Optional[StrictStr] = None
    payment_channel: Optional[StrictStr] = None
    itc: Optional[StrictStr] = None
    processing_code: Optional[StrictStr] = None
    is_track_data_present: Optional[StrictBool] = None
    is_cvv2_present: Optional[StrictBool] = None
    is_cavv_data_present: Optional[StrictBool] = None
    cavv_result_code: Optional[StrictStr] = None
    is_icc_present: Optional[StrictBool] = None
    is_pin_present: Optional[StrictBool] = None
    pan_entry_mode: Optional[StrictStr] = None
    is_cardholder_present: Optional[StrictBool] = None
    is_card_present: Optional[StrictBool] = None
    mcc: Optional[StrictStr] = None
    mid: Optional[StrictStr] = None
    attributes: Optional[Dict[str, StrictStr]] = None
    __properties = ["pcode", "amount", "request_amount", "additional_amount", "acquirer_fee", "refid", "ref_itc", "account2_id", "country", "currency", "settlement_currency", "payment_channel", "itc", "processing_code", "is_track_data_present", "is_cvv2_present", "is_cavv_data_present", "cavv_result_code", "is_icc_present", "is_pin_present", "pan_entry_mode", "is_cardholder_present", "is_card_present", "mcc", "mid", "attributes"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InternalTransactionDataModel:
        """Create an instance of InternalTransactionDataModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InternalTransactionDataModel:
        """Create an instance of InternalTransactionDataModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return InternalTransactionDataModel.parse_obj(obj)

        _obj = InternalTransactionDataModel.parse_obj({
            "pcode": obj.get("pcode"),
            "amount": obj.get("amount"),
            "request_amount": obj.get("request_amount"),
            "additional_amount": obj.get("additional_amount"),
            "acquirer_fee": obj.get("acquirer_fee"),
            "refid": obj.get("refid"),
            "ref_itc": obj.get("ref_itc"),
            "account2_id": obj.get("account2_id"),
            "country": obj.get("country"),
            "currency": obj.get("currency"),
            "settlement_currency": obj.get("settlement_currency"),
            "payment_channel": obj.get("payment_channel"),
            "itc": obj.get("itc"),
            "processing_code": obj.get("processing_code"),
            "is_track_data_present": obj.get("is_track_data_present"),
            "is_cvv2_present": obj.get("is_cvv2_present"),
            "is_cavv_data_present": obj.get("is_cavv_data_present"),
            "cavv_result_code": obj.get("cavv_result_code"),
            "is_icc_present": obj.get("is_icc_present"),
            "is_pin_present": obj.get("is_pin_present"),
            "pan_entry_mode": obj.get("pan_entry_mode"),
            "is_cardholder_present": obj.get("is_cardholder_present"),
            "is_card_present": obj.get("is_card_present"),
            "mcc": obj.get("mcc"),
            "mid": obj.get("mid"),
            "attributes": obj.get("attributes")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictStr, conlist
from marqeta_client.models.internal_funding_source import InternalFundingSource
from marqeta_client.models.internal_gateway_response import InternalGatewayResponse
from marqeta_client.models.velocity_control_check_request import VelocityControlCheckRequest

class AutoCommandoModeRequest(BaseModel):
    """
    AutoCommandoModeRequest
    """
    program_gateway_funding_source: InternalFundingSource = ...
    gateway_response: InternalGatewayResponse = ...
    velocity_control_request: VelocityControlCheckRequest = ...
    mcc_groups: Optional[conlist(StrictStr)] = None
    __properties = ["program_gateway_funding_source", "gateway_response", "velocity_control_request", "mcc_groups"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AutoCommandoModeRequest:
        """Create an instance of AutoCommandoModeRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of program_gateway_funding_source
        if self.program_gateway_funding_source:
            _dict['program_gateway_funding_source'] = self.program_gateway_funding_source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of gateway_response
        if self.gateway_response:
            _dict['gateway_response'] = self.gateway_response.to_dict()
        # override the default output from pydantic by calling `to_dict()` of velocity_control_request
        if self.velocity_control_request:
            _dict['velocity_control_request'] = self.velocity_control_request.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AutoCommandoModeRequest:
        """Create an instance of AutoCommandoModeRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AutoCommandoModeRequest.parse_obj(obj)

        _obj = AutoCommandoModeRequest.parse_obj({
            "program_gateway_funding_source": InternalFundingSource.from_dict(obj.get("program_gateway_funding_source")) if obj.get("program_gateway_funding_source") is not None else None,
            "gateway_response": InternalGatewayResponse.from_dict(obj.get("gateway_response")) if obj.get("gateway_response") is not None else None,
            "velocity_control_request": VelocityControlCheckRequest.from_dict(obj.get("velocity_control_request")) if obj.get("velocity_control_request") is not None else None,
            "mcc_groups": obj.get("mcc_groups")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictStr, conlist
from marqeta_client.models.account import Account
from marqeta_client.models.risk_assessment import RiskAssessment

class WalletProviderProfile(BaseModel):
    """
    WalletProviderProfile
    """
    account: Optional[Account] = None
    risk_assessment: Optional[RiskAssessment] = None
    device_score: Optional[StrictStr] = None
    pan_source: Optional[StrictStr] = None
    reason_code: Optional[StrictStr] = None
    recommendation_reasons: Optional[conlist(StrictStr)] = None
    __properties = ["account", "risk_assessment", "device_score", "pan_source", "reason_code", "recommendation_reasons"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WalletProviderProfile:
        """Create an instance of WalletProviderProfile from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of account
        if self.account:
            _dict['account'] = self.account.to_dict()
        # override the default output from pydantic by calling `to_dict()` of risk_assessment
        if self.risk_assessment:
            _dict['risk_assessment'] = self.risk_assessment.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WalletProviderProfile:
        """Create an instance of WalletProviderProfile from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return WalletProviderProfile.parse_obj(obj)

        _obj = WalletProviderProfile.parse_obj({
            "account": Account.from_dict(obj.get("account")) if obj.get("account") is not None else None,
            "risk_assessment": RiskAssessment.from_dict(obj.get("risk_assessment")) if obj.get("risk_assessment") is not None else None,
            "device_score": obj.get("device_score"),
            "pan_source": obj.get("pan_source"),
            "reason_code": obj.get("reason_code"),
            "recommendation_reasons": obj.get("recommendation_reasons")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr
from marqeta_client.models.funding import Funding
from marqeta_client.models.jit_funding_api import JitFundingApi
from marqeta_client.models.response import Response

class GpaReturns(BaseModel):
    """
    GpaReturns
    """
    token: StrictStr = ...
    amount: Union[StrictFloat, StrictInt] = ...
    tags: Optional[StrictStr] = None
    memo: Optional[StrictStr] = None
    created_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    last_modified_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    transaction_token: StrictStr = ...
    state: StrictStr = ...
    response: Response = ...
    funding: Funding = ...
    funding_source_token: StrictStr = ...
    funding_source_address_token: Optional[StrictStr] = None
    jit_funding: Optional[JitFundingApi] = None
    original_order_token: Optional[StrictStr] = None
    __properties = ["token", "amount", "tags", "memo", "created_time", "last_modified_time", "transaction_token", "state", "response", "funding", "funding_source_token", "funding_source_address_token", "jit_funding", "original_order_token"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GpaReturns:
        """Create an instance of GpaReturns from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of response
        if self.response:
            _dict['response'] = self.response.to_dict()
        # override the default output from pydantic by calling `to_dict()` of funding
        if self.funding:
            _dict['funding'] = self.funding.to_dict()
        # override the default output from pydantic by calling `to_dict()` of jit_funding
        if self.jit_funding:
            _dict['jit_funding'] = self.jit_funding.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GpaReturns:
        """Create an instance of GpaReturns from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return GpaReturns.parse_obj(obj)

        _obj = GpaReturns.parse_obj({
            "token": obj.get("token"),
            "amount": obj.get("amount"),
            "tags": obj.get("tags"),
            "memo": obj.get("memo"),
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "transaction_token": obj.get("transaction_token"),
            "state": obj.get("state"),
            "response": Response.from_dict(obj.get("response")) if obj.get("response") is not None else None,
            "funding": Funding.from_dict(obj.get("funding")) if obj.get("funding") is not None else None,
            "funding_source_token": obj.get("funding_source_token"),
            "funding_source_address_token": obj.get("funding_source_address_token"),
            "jit_funding": JitFundingApi.from_dict(obj.get("jit_funding")) if obj.get("jit_funding") is not None else None,
            "original_order_token": obj.get("original_order_token")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr

class BaseAchExtendedResponseModel(BaseModel):
    """
    BaseAchExtendedResponseModel
    """
    created_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    last_modified_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    token: StrictStr = ...
    account_suffix: StrictStr = ...
    verification_status: Optional[StrictStr] = None
    account_type: StrictStr = ...
    name_on_account: StrictStr = ...
    bank_name: Optional[StrictStr] = None
    active: StrictBool = ...
    date_sent_for_verification: Optional[datetime] = None
    partner: Optional[StrictStr] = None
    partner_account_link_reference_token: Optional[StrictStr] = None
    is_default_account: Optional[StrictBool] = False
    date_verified: Optional[datetime] = None
    verification_override: Optional[StrictBool] = False
    verification_notes: Optional[StrictStr] = None
    routing_number: Optional[StrictStr] = None
    account_number: Optional[StrictStr] = None
    __properties = ["created_time", "last_modified_time", "token", "account_suffix", "verification_status", "account_type", "name_on_account", "bank_name", "active", "date_sent_for_verification", "partner", "partner_account_link_reference_token", "is_default_account", "date_verified", "verification_override", "verification_notes", "routing_number", "account_number"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BaseAchExtendedResponseModel:
        """Create an instance of BaseAchExtendedResponseModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BaseAchExtendedResponseModel:
        """Create an instance of BaseAchExtendedResponseModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return BaseAchExtendedResponseModel.parse_obj(obj)

        _obj = BaseAchExtendedResponseModel.parse_obj({
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "token": obj.get("token"),
            "account_suffix": obj.get("account_suffix"),
            "verification_status": obj.get("verification_status"),
            "account_type": obj.get("account_type"),
            "name_on_account": obj.get("name_on_account"),
            "bank_name": obj.get("bank_name"),
            "active": obj.get("active") if obj.get("active") is not None else False,
            "date_sent_for_verification": obj.get("date_sent_for_verification"),
            "partner": obj.get("partner"),
            "partner_account_link_reference_token": obj.get("partner_account_link_reference_token"),
            "is_default_account": obj.get("is_default_account") if obj.get("is_default_account") is not None else False,
            "date_verified": obj.get("date_verified"),
            "verification_override": obj.get("verification_override") if obj.get("verification_override") is not None else False,
            "verification_notes": obj.get("verification_notes"),
            "routing_number": obj.get("routing_number"),
            "account_number": obj.get("account_number")
        })
        return _obj




# flake8: noqa

# import apis into api package
from marqeta_client.api.accepted_countries_api import AcceptedCountriesApi
from marqeta_client.api.account_holder_groups_api import AccountHolderGroupsApi
from marqeta_client.api.auth_controls_api import AuthControlsApi
from marqeta_client.api.auto_reloads_api import AutoReloadsApi
from marqeta_client.api.bank_transfers_api import BankTransfersApi
from marqeta_client.api.bulk_issuances_api import BulkIssuancesApi
from marqeta_client.api.business_transitions_api import BusinessTransitionsApi
from marqeta_client.api.businesses_api import BusinessesApi
from marqeta_client.api.card_products_api import CardProductsApi
from marqeta_client.api.card_transitions_api import CardTransitionsApi
from marqeta_client.api.cardholder_balances_api import CardholderBalancesApi
from marqeta_client.api.cards_api import CardsApi
from marqeta_client.api.chargebacks_api import ChargebacksApi
from marqeta_client.api.commando_modes_api import CommandoModesApi
from marqeta_client.api.digital_wallet_provision_requests_api import DigitalWalletProvisionRequestsApi
from marqeta_client.api.digital_wallet_token_transitions_api import DigitalWalletTokenTransitionsApi
from marqeta_client.api.digital_wallet_tokens_api import DigitalWalletTokensApi
from marqeta_client.api.direct_deposit_accounts_api import DirectDepositAccountsApi
from marqeta_client.api.direct_deposits_api import DirectDepositsApi
from marqeta_client.api.fee_transfers_api import FeeTransfersApi
from marqeta_client.api.fees_api import FeesApi
from marqeta_client.api.funding_sources_api import FundingSourcesApi
from marqeta_client.api.gpa_orders_api import GpaOrdersApi
from marqeta_client.api.kyc_api import KycApi
from marqeta_client.api.mcc_groups_api import MccGroupsApi
from marqeta_client.api.merchantgroups_api import MerchantgroupsApi
from marqeta_client.api.peer_transfers_api import PeerTransfersApi
from marqeta_client.api.ping_api import PingApi
from marqeta_client.api.pins_api import PinsApi
from marqeta_client.api.program_reserve_api import ProgramReserveApi
from marqeta_client.api.program_transfers_api import ProgramTransfersApi
from marqeta_client.api.push_to_card_api import PushToCardApi
from marqeta_client.api.real_time_fee_groups_api import RealTimeFeeGroupsApi
from marqeta_client.api.simulate_api import SimulateApi
from marqeta_client.api.transactions_api import TransactionsApi
from marqeta_client.api.user_transitions_api import UserTransitionsApi
from marqeta_client.api.users_api import UsersApi
from marqeta_client.api.velocity_controls_api import VelocityControlsApi
from marqeta_client.api.web_push_provisioning_api import WebPushProvisioningApi
from marqeta_client.api.webhooks_api import WebhooksApi




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, constr, validator

class Iso8583DigitalWalletToken(BaseModel):
    """
    Iso8583DigitalWalletToken
    """
    token_pan: Optional[constr(strict=True, max_length=19, min_length=0)] = None
    token_assurance_level: Optional[constr(strict=True, max_length=2, min_length=0)] = None
    token_requestor_id: Optional[constr(strict=True, max_length=11, min_length=0)] = None
    token_reference_id: Optional[constr(strict=True, max_length=50, min_length=0)] = None
    correlation_id: Optional[constr(strict=True, max_length=50, min_length=0)] = None
    token_expiry_date: Optional[constr(strict=True, max_length=4, min_length=0)] = None
    token_type: Optional[StrictStr] = None
    token_status: Optional[StrictStr] = None
    pan_reference_id: Optional[constr(strict=True, max_length=50, min_length=0)] = None
    network_token_score: Optional[constr(strict=True, max_length=2, min_length=0)] = None
    network_decisioning: Optional[StrictStr] = None
    number_of_active_tokens: Optional[constr(strict=True, max_length=2, min_length=0)] = None
    number_of_inactive_tokens: Optional[constr(strict=True, max_length=2, min_length=0)] = None
    number_of_suspended_tokens: Optional[constr(strict=True, max_length=2, min_length=0)] = None
    issuer_terms_and_condition: Optional[constr(strict=True, max_length=64, min_length=0)] = None
    issuer_terms_and_condition_date: Optional[datetime] = Field(None, description="yyyy-MM-dd, yyyy-MM-ddThh:mm:ssZ")
    elapsed_time_to_live: Optional[StrictInt] = None
    number_of_transactions: Optional[StrictInt] = None
    cumulative_transaction_amount: Optional[Union[StrictFloat, StrictInt]] = None
    number_of_activation_attempts: Optional[StrictInt] = None
    visa_auto_fill_indicator: Optional[StrictBool] = None
    __properties = ["token_pan", "token_assurance_level", "token_requestor_id", "token_reference_id", "correlation_id", "token_expiry_date", "token_type", "token_status", "pan_reference_id", "network_token_score", "network_decisioning", "number_of_active_tokens", "number_of_inactive_tokens", "number_of_suspended_tokens", "issuer_terms_and_condition", "issuer_terms_and_condition_date", "elapsed_time_to_live", "number_of_transactions", "cumulative_transaction_amount", "number_of_activation_attempts", "visa_auto_fill_indicator"]

    @validator('token_type')
    def token_type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('DEVICE_SECURE_ELEMENT', 'DEVICE_CLOUD_BASED', 'MERCHANT_CARD_ON_FILE', 'ECOMMERCE_DIGITAL_WALLET', 'PSEUDO_ACCOUNT'):
            raise ValueError("must be one of enum values ('DEVICE_SECURE_ELEMENT', 'DEVICE_CLOUD_BASED', 'MERCHANT_CARD_ON_FILE', 'ECOMMERCE_DIGITAL_WALLET', 'PSEUDO_ACCOUNT')")
        return v

    @validator('token_status')
    def token_status_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('REQUESTED', 'ACTIVE', 'SUSPENDED', 'TERMINATED'):
            raise ValueError("must be one of enum values ('REQUESTED', 'ACTIVE', 'SUSPENDED', 'TERMINATED')")
        return v

    @validator('network_decisioning')
    def network_decisioning_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('DECISION_GREEN', 'DECISION_YELLOW', 'DECISION_RED'):
            raise ValueError("must be one of enum values ('DECISION_GREEN', 'DECISION_YELLOW', 'DECISION_RED')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Iso8583DigitalWalletToken:
        """Create an instance of Iso8583DigitalWalletToken from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Iso8583DigitalWalletToken:
        """Create an instance of Iso8583DigitalWalletToken from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Iso8583DigitalWalletToken.parse_obj(obj)

        _obj = Iso8583DigitalWalletToken.parse_obj({
            "token_pan": obj.get("token_pan"),
            "token_assurance_level": obj.get("token_assurance_level"),
            "token_requestor_id": obj.get("token_requestor_id"),
            "token_reference_id": obj.get("token_reference_id"),
            "correlation_id": obj.get("correlation_id"),
            "token_expiry_date": obj.get("token_expiry_date"),
            "token_type": obj.get("token_type"),
            "token_status": obj.get("token_status"),
            "pan_reference_id": obj.get("pan_reference_id"),
            "network_token_score": obj.get("network_token_score"),
            "network_decisioning": obj.get("network_decisioning"),
            "number_of_active_tokens": obj.get("number_of_active_tokens"),
            "number_of_inactive_tokens": obj.get("number_of_inactive_tokens"),
            "number_of_suspended_tokens": obj.get("number_of_suspended_tokens"),
            "issuer_terms_and_condition": obj.get("issuer_terms_and_condition"),
            "issuer_terms_and_condition_date": obj.get("issuer_terms_and_condition_date"),
            "elapsed_time_to_live": obj.get("elapsed_time_to_live"),
            "number_of_transactions": obj.get("number_of_transactions"),
            "cumulative_transaction_amount": obj.get("cumulative_transaction_amount"),
            "number_of_activation_attempts": obj.get("number_of_activation_attempts"),
            "visa_auto_fill_indicator": obj.get("visa_auto_fill_indicator")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool
from marqeta_client.models.in_app_provisioning import InAppProvisioning
from marqeta_client.models.manual_entry import ManualEntry
from marqeta_client.models.wallet_provider_card_on_file import WalletProviderCardOnFile
from marqeta_client.models.web_push_provisioning import WebPushProvisioning

class ProvisioningControls(BaseModel):
    """
    ProvisioningControls
    """
    manual_entry: Optional[ManualEntry] = None
    wallet_provider_card_on_file: Optional[WalletProviderCardOnFile] = None
    in_app_provisioning: Optional[InAppProvisioning] = None
    web_push_provisioning: Optional[WebPushProvisioning] = None
    force_yellow_path_for_card_product: Optional[StrictBool] = None
    __properties = ["manual_entry", "wallet_provider_card_on_file", "in_app_provisioning", "web_push_provisioning", "force_yellow_path_for_card_product"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ProvisioningControls:
        """Create an instance of ProvisioningControls from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of manual_entry
        if self.manual_entry:
            _dict['manual_entry'] = self.manual_entry.to_dict()
        # override the default output from pydantic by calling `to_dict()` of wallet_provider_card_on_file
        if self.wallet_provider_card_on_file:
            _dict['wallet_provider_card_on_file'] = self.wallet_provider_card_on_file.to_dict()
        # override the default output from pydantic by calling `to_dict()` of in_app_provisioning
        if self.in_app_provisioning:
            _dict['in_app_provisioning'] = self.in_app_provisioning.to_dict()
        # override the default output from pydantic by calling `to_dict()` of web_push_provisioning
        if self.web_push_provisioning:
            _dict['web_push_provisioning'] = self.web_push_provisioning.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ProvisioningControls:
        """Create an instance of ProvisioningControls from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ProvisioningControls.parse_obj(obj)

        _obj = ProvisioningControls.parse_obj({
            "manual_entry": ManualEntry.from_dict(obj.get("manual_entry")) if obj.get("manual_entry") is not None else None,
            "wallet_provider_card_on_file": WalletProviderCardOnFile.from_dict(obj.get("wallet_provider_card_on_file")) if obj.get("wallet_provider_card_on_file") is not None else None,
            "in_app_provisioning": InAppProvisioning.from_dict(obj.get("in_app_provisioning")) if obj.get("in_app_provisioning") is not None else None,
            "web_push_provisioning": WebPushProvisioning.from_dict(obj.get("web_push_provisioning")) if obj.get("web_push_provisioning") is not None else None,
            "force_yellow_path_for_card_product": obj.get("force_yellow_path_for_card_product")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr

from typing import Optional

from marqeta_client.models.access_token_response import AccessTokenResponse
from marqeta_client.models.card_holder_model import CardHolderModel
from marqeta_client.models.card_holder_note_list_response import CardHolderNoteListResponse
from marqeta_client.models.cardholder_note_request_model import CardholderNoteRequestModel
from marqeta_client.models.cardholder_note_response_model import CardholderNoteResponseModel
from marqeta_client.models.cardholder_note_update_request_model import CardholderNoteUpdateRequestModel
from marqeta_client.models.client_access_token_request import ClientAccessTokenRequest
from marqeta_client.models.client_access_token_response import ClientAccessTokenResponse
from marqeta_client.models.login_request_model import LoginRequestModel
from marqeta_client.models.login_response_model import LoginResponseModel
from marqeta_client.models.one_time_request_model import OneTimeRequestModel
from marqeta_client.models.password_update_model import PasswordUpdateModel
from marqeta_client.models.reset_user_password_email_model import ResetUserPasswordEmailModel
from marqeta_client.models.reset_user_password_model import ResetUserPasswordModel
from marqeta_client.models.ssn_response_model import SsnResponseModel
from marqeta_client.models.user_card_holder_list_response import UserCardHolderListResponse
from marqeta_client.models.user_card_holder_response import UserCardHolderResponse
from marqeta_client.models.user_card_holder_search_model import UserCardHolderSearchModel
from marqeta_client.models.user_card_holder_update_model import UserCardHolderUpdateModel

from marqeta_client.api_client import ApiClient
from marqeta_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class UsersApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_users(self, count : Annotated[Optional[StrictInt], Field(description="Number of users to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, search_type : Annotated[Optional[StrictStr], Field(description="Search type")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, **kwargs) -> UserCardHolderListResponse:  # noqa: E501
        """Lists all users  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_users(count, start_index, search_type, fields, sort_by, async_req=True)
        >>> result = thread.get()

        :param count: Number of users to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param search_type: Search type
        :type search_type: str
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserCardHolderListResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_users_with_http_info(count, start_index, search_type, fields, sort_by, **kwargs)  # noqa: E501

    @validate_arguments
    def get_users_with_http_info(self, count : Annotated[Optional[StrictInt], Field(description="Number of users to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, search_type : Annotated[Optional[StrictStr], Field(description="Search type")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, **kwargs):  # noqa: E501
        """Lists all users  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_users_with_http_info(count, start_index, search_type, fields, sort_by, async_req=True)
        >>> result = thread.get()

        :param count: Number of users to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param search_type: Search type
        :type search_type: str
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(UserCardHolderListResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'count',
            'start_index',
            'search_type',
            'fields',
            'sort_by'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('count') is not None:  # noqa: E501
            _query_params.append(('count', _params['count']))

        if _params.get('start_index') is not None:  # noqa: E501
            _query_params.append(('start_index', _params['start_index']))

        if _params.get('search_type') is not None:  # noqa: E501
            _query_params.append(('search_type', _params['search_type']))

        if _params.get('fields') is not None:  # noqa: E501
            _query_params.append(('fields', _params['fields']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sort_by', _params['sort_by']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "UserCardHolderListResponse",
            '400': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/users', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_users_auth_clientaccesstoken_token(self, token : Annotated[StrictStr, Field(..., description="Client access token")], application_token : Optional[StrictStr] = None, **kwargs) -> ClientAccessTokenResponse:  # noqa: E501
        """Returns a client access token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_users_auth_clientaccesstoken_token(token, application_token, async_req=True)
        >>> result = thread.get()

        :param token: Client access token (required)
        :type token: str
        :param application_token:
        :type application_token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ClientAccessTokenResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_users_auth_clientaccesstoken_token_with_http_info(token, application_token, **kwargs)  # noqa: E501

    @validate_arguments
    def get_users_auth_clientaccesstoken_token_with_http_info(self, token : Annotated[StrictStr, Field(..., description="Client access token")], application_token : Optional[StrictStr] = None, **kwargs):  # noqa: E501
        """Returns a client access token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_users_auth_clientaccesstoken_token_with_http_info(token, application_token, async_req=True)
        >>> result = thread.get()

        :param token: Client access token (required)
        :type token: str
        :param application_token:
        :type application_token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ClientAccessTokenResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token',
            'application_token'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_auth_clientaccesstoken_token" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        if _params.get('application_token') is not None:  # noqa: E501
            _query_params.append(('application_token', _params['application_token']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "ClientAccessTokenResponse",
            '400': None,
            '401': None,
            '403': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/users/auth/clientaccesstoken/{token}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_users_parenttoken_children(self, parent_token : Annotated[StrictStr, Field(..., description="Token of parent cardholder")], count : Annotated[Optional[StrictInt], Field(description="Number of users to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, **kwargs) -> UserCardHolderListResponse:  # noqa: E501
        """Lists all children of a parent user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_users_parenttoken_children(parent_token, count, start_index, fields, sort_by, async_req=True)
        >>> result = thread.get()

        :param parent_token: Token of parent cardholder (required)
        :type parent_token: str
        :param count: Number of users to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserCardHolderListResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_users_parenttoken_children_with_http_info(parent_token, count, start_index, fields, sort_by, **kwargs)  # noqa: E501

    @validate_arguments
    def get_users_parenttoken_children_with_http_info(self, parent_token : Annotated[StrictStr, Field(..., description="Token of parent cardholder")], count : Annotated[Optional[StrictInt], Field(description="Number of users to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, **kwargs):  # noqa: E501
        """Lists all children of a parent user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_users_parenttoken_children_with_http_info(parent_token, count, start_index, fields, sort_by, async_req=True)
        >>> result = thread.get()

        :param parent_token: Token of parent cardholder (required)
        :type parent_token: str
        :param count: Number of users to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(UserCardHolderListResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'parent_token',
            'count',
            'start_index',
            'fields',
            'sort_by'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_parenttoken_children" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['parent_token']:
            _path_params['parent_token'] = _params['parent_token']


        # process the query parameters
        _query_params = []
        if _params.get('count') is not None:  # noqa: E501
            _query_params.append(('count', _params['count']))

        if _params.get('start_index') is not None:  # noqa: E501
            _query_params.append(('start_index', _params['start_index']))

        if _params.get('fields') is not None:  # noqa: E501
            _query_params.append(('fields', _params['fields']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sort_by', _params['sort_by']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "UserCardHolderListResponse",
            '400': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/users/{parent_token}/children', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_users_phonenumber_phonenumber(self, phone_number : Annotated[StrictStr, Field(..., description="Phone number")], count : Annotated[Optional[StrictInt], Field(description="Number of users to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, **kwargs) -> UserCardHolderListResponse:  # noqa: E501
        """Lists all users who match a phone number  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_users_phonenumber_phonenumber(phone_number, count, start_index, fields, sort_by, async_req=True)
        >>> result = thread.get()

        :param phone_number: Phone number (required)
        :type phone_number: str
        :param count: Number of users to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserCardHolderListResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_users_phonenumber_phonenumber_with_http_info(phone_number, count, start_index, fields, sort_by, **kwargs)  # noqa: E501

    @validate_arguments
    def get_users_phonenumber_phonenumber_with_http_info(self, phone_number : Annotated[StrictStr, Field(..., description="Phone number")], count : Annotated[Optional[StrictInt], Field(description="Number of users to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, **kwargs):  # noqa: E501
        """Lists all users who match a phone number  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_users_phonenumber_phonenumber_with_http_info(phone_number, count, start_index, fields, sort_by, async_req=True)
        >>> result = thread.get()

        :param phone_number: Phone number (required)
        :type phone_number: str
        :param count: Number of users to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(UserCardHolderListResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'phone_number',
            'count',
            'start_index',
            'fields',
            'sort_by'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_phonenumber_phonenumber" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['phone_number']:
            _path_params['phone_number'] = _params['phone_number']


        # process the query parameters
        _query_params = []
        if _params.get('count') is not None:  # noqa: E501
            _query_params.append(('count', _params['count']))

        if _params.get('start_index') is not None:  # noqa: E501
            _query_params.append(('start_index', _params['start_index']))

        if _params.get('fields') is not None:  # noqa: E501
            _query_params.append(('fields', _params['fields']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sort_by', _params['sort_by']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "UserCardHolderListResponse",
            '400': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/users/phonenumber/{phone_number}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_users_token(self, token : Annotated[StrictStr, Field(..., description="User token")], fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, **kwargs) -> UserCardHolderResponse:  # noqa: E501
        """Returns a specific user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_users_token(token, fields, async_req=True)
        >>> result = thread.get()

        :param token: User token (required)
        :type token: str
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserCardHolderResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_users_token_with_http_info(token, fields, **kwargs)  # noqa: E501

    @validate_arguments
    def get_users_token_with_http_info(self, token : Annotated[StrictStr, Field(..., description="User token")], fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, **kwargs):  # noqa: E501
        """Returns a specific user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_users_token_with_http_info(token, fields, async_req=True)
        >>> result = thread.get()

        :param token: User token (required)
        :type token: str
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(UserCardHolderResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token',
            'fields'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_token" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        if _params.get('fields') is not None:  # noqa: E501
            _query_params.append(('fields', _params['fields']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "UserCardHolderResponse",
            '400': None,
            '404': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/users/{token}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_users_token_notes(self, token : Annotated[StrictStr, Field(..., description="User token")], start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, count : Annotated[Optional[StrictInt], Field(description="Number of notes to retrieve")] = None, created_by : Annotated[Optional[StrictStr], Field(description="Created by")] = None, created_by_user_role : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of created by user roles")] = None, include_private : Annotated[Optional[StrictBool], Field(description="Include private notes and private fields in note response")] = None, search_type : Annotated[Optional[StrictStr], Field(description="Search type")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, **kwargs) -> CardHolderNoteListResponse:  # noqa: E501
        """Lists cardholder notes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_users_token_notes(token, start_index, count, created_by, created_by_user_role, include_private, search_type, fields, sort_by, async_req=True)
        >>> result = thread.get()

        :param token: User token (required)
        :type token: str
        :param start_index: Start index
        :type start_index: int
        :param count: Number of notes to retrieve
        :type count: int
        :param created_by: Created by
        :type created_by: str
        :param created_by_user_role: Comma-delimited list of created by user roles
        :type created_by_user_role: str
        :param include_private: Include private notes and private fields in note response
        :type include_private: bool
        :param search_type: Search type
        :type search_type: str
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CardHolderNoteListResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_users_token_notes_with_http_info(token, start_index, count, created_by, created_by_user_role, include_private, search_type, fields, sort_by, **kwargs)  # noqa: E501

    @validate_arguments
    def get_users_token_notes_with_http_info(self, token : Annotated[StrictStr, Field(..., description="User token")], start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, count : Annotated[Optional[StrictInt], Field(description="Number of notes to retrieve")] = None, created_by : Annotated[Optional[StrictStr], Field(description="Created by")] = None, created_by_user_role : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of created by user roles")] = None, include_private : Annotated[Optional[StrictBool], Field(description="Include private notes and private fields in note response")] = None, search_type : Annotated[Optional[StrictStr], Field(description="Search type")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, **kwargs):  # noqa: E501
        """Lists cardholder notes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_users_token_notes_with_http_info(token, start_index, count, created_by, created_by_user_role, include_private, search_type, fields, sort_by, async_req=True)
        >>> result = thread.get()

        :param token: User token (required)
        :type token: str
        :param start_index: Start index
        :type start_index: int
        :param count: Number of notes to retrieve
        :type count: int
        :param created_by: Created by
        :type created_by: str
        :param created_by_user_role: Comma-delimited list of created by user roles
        :type created_by_user_role: str
        :param include_private: Include private notes and private fields in note response
        :type include_private: bool
        :param search_type: Search type
        :type search_type: str
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CardHolderNoteListResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token',
            'start_index',
            'count',
            'created_by',
            'created_by_user_role',
            'include_private',
            'search_type',
            'fields',
            'sort_by'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_token_notes" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        if _params.get('start_index') is not None:  # noqa: E501
            _query_params.append(('start_index', _params['start_index']))

        if _params.get('count') is not None:  # noqa: E501
            _query_params.append(('count', _params['count']))

        if _params.get('created_by') is not None:  # noqa: E501
            _query_params.append(('created_by', _params['created_by']))

        if _params.get('created_by_user_role') is not None:  # noqa: E501
            _query_params.append(('created_by_user_role', _params['created_by_user_role']))

        if _params.get('include_private') is not None:  # noqa: E501
            _query_params.append(('include_private', _params['include_private']))

        if _params.get('search_type') is not None:  # noqa: E501
            _query_params.append(('search_type', _params['search_type']))

        if _params.get('fields') is not None:  # noqa: E501
            _query_params.append(('fields', _params['fields']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sort_by', _params['sort_by']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "CardHolderNoteListResponse",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/users/{token}/notes', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_users_token_ssn(self, token : Annotated[StrictStr, Field(..., description="User token")], full_ssn : Optional[StrictBool] = None, **kwargs) -> SsnResponseModel:  # noqa: E501
        """Returns a specific user's SSN  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_users_token_ssn(token, full_ssn, async_req=True)
        >>> result = thread.get()

        :param token: User token (required)
        :type token: str
        :param full_ssn:
        :type full_ssn: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SsnResponseModel
        """
        kwargs['_return_http_data_only'] = True
        return self.get_users_token_ssn_with_http_info(token, full_ssn, **kwargs)  # noqa: E501

    @validate_arguments
    def get_users_token_ssn_with_http_info(self, token : Annotated[StrictStr, Field(..., description="User token")], full_ssn : Optional[StrictBool] = None, **kwargs):  # noqa: E501
        """Returns a specific user's SSN  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_users_token_ssn_with_http_info(token, full_ssn, async_req=True)
        >>> result = thread.get()

        :param token: User token (required)
        :type token: str
        :param full_ssn:
        :type full_ssn: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SsnResponseModel, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token',
            'full_ssn'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users_token_ssn" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        if _params.get('full_ssn') is not None:  # noqa: E501
            _query_params.append(('full_ssn', _params['full_ssn']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "SsnResponseModel",
            '400': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/users/{token}/ssn', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_users(self, body : Optional[CardHolderModel] = None, **kwargs) -> UserCardHolderResponse:  # noqa: E501
        """Creates a user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users(body, async_req=True)
        >>> result = thread.get()

        :param body:
        :type body: CardHolderModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserCardHolderResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.post_users_with_http_info(body, **kwargs)  # noqa: E501

    @validate_arguments
    def post_users_with_http_info(self, body : Optional[CardHolderModel] = None, **kwargs):  # noqa: E501
        """Creates a user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param body:
        :type body: CardHolderModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(UserCardHolderResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '201': "UserCardHolderResponse",
            '400': None,
            '409': None,
            '412': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/users', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_users_auth_changepassword(self, body : Annotated[PasswordUpdateModel, Field(..., description="Password update object")], **kwargs) -> None:  # noqa: E501
        """Updates a user password  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_changepassword(body, async_req=True)
        >>> result = thread.get()

        :param body: Password update object (required)
        :type body: PasswordUpdateModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.post_users_auth_changepassword_with_http_info(body, **kwargs)  # noqa: E501

    @validate_arguments
    def post_users_auth_changepassword_with_http_info(self, body : Annotated[PasswordUpdateModel, Field(..., description="Password update object")], **kwargs):  # noqa: E501
        """Updates a user password  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_changepassword_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param body: Password update object (required)
        :type body: PasswordUpdateModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_auth_changepassword" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/users/auth/changepassword', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_users_auth_clientaccesstoken(self, body : Optional[ClientAccessTokenRequest] = None, **kwargs) -> ClientAccessTokenResponse:  # noqa: E501
        """Creates a client access token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_clientaccesstoken(body, async_req=True)
        >>> result = thread.get()

        :param body:
        :type body: ClientAccessTokenRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ClientAccessTokenResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.post_users_auth_clientaccesstoken_with_http_info(body, **kwargs)  # noqa: E501

    @validate_arguments
    def post_users_auth_clientaccesstoken_with_http_info(self, body : Optional[ClientAccessTokenRequest] = None, **kwargs):  # noqa: E501
        """Creates a client access token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_clientaccesstoken_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param body:
        :type body: ClientAccessTokenRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ClientAccessTokenResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_auth_clientaccesstoken" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '201': "ClientAccessTokenResponse",
            '400': None,
            '401': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/users/auth/clientaccesstoken', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_users_auth_login(self, body : Annotated[Optional[LoginRequestModel], Field(description="User login object")] = None, **kwargs) -> LoginResponseModel:  # noqa: E501
        """Logs in a user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_login(body, async_req=True)
        >>> result = thread.get()

        :param body: User login object
        :type body: LoginRequestModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: LoginResponseModel
        """
        kwargs['_return_http_data_only'] = True
        return self.post_users_auth_login_with_http_info(body, **kwargs)  # noqa: E501

    @validate_arguments
    def post_users_auth_login_with_http_info(self, body : Annotated[Optional[LoginRequestModel], Field(description="User login object")] = None, **kwargs):  # noqa: E501
        """Logs in a user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_login_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param body: User login object
        :type body: LoginRequestModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(LoginResponseModel, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_auth_login" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '204': "LoginResponseModel",
            '400': None,
            '401': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/users/auth/login', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_users_auth_logout(self, **kwargs) -> None:  # noqa: E501
        """Logs out a user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_logout(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.post_users_auth_logout_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    def post_users_auth_logout_with_http_info(self, **kwargs):  # noqa: E501
        """Logs out a user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_logout_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_auth_logout" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/users/auth/logout', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_users_auth_onetime(self, body : Annotated[Optional[OneTimeRequestModel], Field(description="One-time object")] = None, **kwargs) -> AccessTokenResponse:  # noqa: E501
        """Creates a one-time token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_onetime(body, async_req=True)
        >>> result = thread.get()

        :param body: One-time object
        :type body: OneTimeRequestModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AccessTokenResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.post_users_auth_onetime_with_http_info(body, **kwargs)  # noqa: E501

    @validate_arguments
    def post_users_auth_onetime_with_http_info(self, body : Annotated[Optional[OneTimeRequestModel], Field(description="One-time object")] = None, **kwargs):  # noqa: E501
        """Creates a one-time token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_onetime_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param body: One-time object
        :type body: OneTimeRequestModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(AccessTokenResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_auth_onetime" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '201': "AccessTokenResponse",
            '400': None,
            '401': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/users/auth/onetime', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_users_auth_resetpassword(self, body : Optional[ResetUserPasswordEmailModel] = None, **kwargs) -> None:  # noqa: E501
        """Generates a reset password email  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_resetpassword(body, async_req=True)
        >>> result = thread.get()

        :param body:
        :type body: ResetUserPasswordEmailModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.post_users_auth_resetpassword_with_http_info(body, **kwargs)  # noqa: E501

    @validate_arguments
    def post_users_auth_resetpassword_with_http_info(self, body : Optional[ResetUserPasswordEmailModel] = None, **kwargs):  # noqa: E501
        """Generates a reset password email  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_resetpassword_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param body:
        :type body: ResetUserPasswordEmailModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_auth_resetpassword" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/users/auth/resetpassword', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_users_auth_resetpassword_token(self, token : Annotated[StrictStr, Field(..., description="Reset password verification token")], body : Optional[ResetUserPasswordModel] = None, **kwargs) -> None:  # noqa: E501
        """Resets a user password  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_resetpassword_token(token, body, async_req=True)
        >>> result = thread.get()

        :param token: Reset password verification token (required)
        :type token: str
        :param body:
        :type body: ResetUserPasswordModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.post_users_auth_resetpassword_token_with_http_info(token, body, **kwargs)  # noqa: E501

    @validate_arguments
    def post_users_auth_resetpassword_token_with_http_info(self, token : Annotated[StrictStr, Field(..., description="Reset password verification token")], body : Optional[ResetUserPasswordModel] = None, **kwargs):  # noqa: E501
        """Resets a user password  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_resetpassword_token_with_http_info(token, body, async_req=True)
        >>> result = thread.get()

        :param token: Reset password verification token (required)
        :type token: str
        :param body:
        :type body: ResetUserPasswordModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'token',
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_auth_resetpassword_token" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/users/auth/resetpassword/{token}', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_users_auth_verifyemail(self, **kwargs) -> None:  # noqa: E501
        """Generates an email verification request  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_verifyemail(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.post_users_auth_verifyemail_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    def post_users_auth_verifyemail_with_http_info(self, **kwargs):  # noqa: E501
        """Generates an email verification request  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_verifyemail_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_auth_verifyemail" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/users/auth/verifyemail', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_users_auth_verifyemail_token(self, token : Annotated[StrictStr, Field(..., description="Email verification token")], **kwargs) -> None:  # noqa: E501
        """Verifies the email token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_verifyemail_token(token, async_req=True)
        >>> result = thread.get()

        :param token: Email verification token (required)
        :type token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.post_users_auth_verifyemail_token_with_http_info(token, **kwargs)  # noqa: E501

    @validate_arguments
    def post_users_auth_verifyemail_token_with_http_info(self, token : Annotated[StrictStr, Field(..., description="Email verification token")], **kwargs):  # noqa: E501
        """Verifies the email token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_auth_verifyemail_token_with_http_info(token, async_req=True)
        >>> result = thread.get()

        :param token: Email verification token (required)
        :type token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'token'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_auth_verifyemail_token" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/users/auth/verifyemail/{token}', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_users_lookup(self, count : Annotated[Optional[StrictInt], Field(description="Number of users to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, search_type : Annotated[Optional[StrictStr], Field(description="Search type")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, body : Optional[UserCardHolderSearchModel] = None, **kwargs) -> UserCardHolderListResponse:  # noqa: E501
        """Lists all users  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_lookup(count, start_index, search_type, fields, sort_by, body, async_req=True)
        >>> result = thread.get()

        :param count: Number of users to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param search_type: Search type
        :type search_type: str
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param body:
        :type body: UserCardHolderSearchModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UserCardHolderListResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.post_users_lookup_with_http_info(count, start_index, search_type, fields, sort_by, body, **kwargs)  # noqa: E501

    @validate_arguments
    def post_users_lookup_with_http_info(self, count : Annotated[Optional[StrictInt], Field(description="Number of users to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, search_type : Annotated[Optional[StrictStr], Field(description="Search type")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, body : Optional[UserCardHolderSearchModel] = None, **kwargs):  # noqa: E501
        """Lists all users  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_lookup_with_http_info(count, start_index, search_type, fields, sort_by, body, async_req=True)
        >>> result = thread.get()

        :param count: Number of users to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param search_type: Search type
        :type search_type: str
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param body:
        :type body: UserCardHolderSearchModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(UserCardHolderListResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'count',
            'start_index',
            'search_type',
            'fields',
            'sort_by',
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_lookup" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('count') is not None:  # noqa: E501
            _query_params.append(('count', _params['count']))

        if _params.get('start_index') is not None:  # noqa: E501
            _query_params.append(('start_index', _params['start_index']))

        if _params.get('search_type') is not None:  # noqa: E501
            _query_params.append(('search_type', _params['search_type']))

        if _params.get('fields') is not None:  # noqa: E501
            _query_params.append(('fields', _params['fields']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sort_by', _params['sort_by']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "UserCardHolderListResponse",
            '400': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/users/lookup', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def post_users_token_notes(self, token : Annotated[StrictStr, Field(..., description="User token")], body : Optional[CardholderNoteRequestModel] = None, **kwargs) -> CardholderNoteResponseModel:  # noqa: E501
        """Creates a note for the cardholder  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_token_notes(token, body, async_req=True)
        >>> result = thread.get()

        :param token: User token (required)
        :type token: str
        :param body:
        :type body: CardholderNoteRequestModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CardholderNoteResponseModel
        """
        kwargs['_return_http_data_only'] = True
        return self.post_users_token_notes_with_http_info(token, body, **kwargs)  # noqa: E501

    @validate_arguments
    def post_users_token_notes_with_http_info(self, token : Annotated[StrictStr, Field(..., description="User token")], body : Optional[CardholderNoteRequestModel] = None, **kwargs):  # noqa: E501
        """Creates a note for the cardholder  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_users_token_notes_with_http_info(token, body, async_req=True)
        >>> result = thread.get()

        :param token: User token (required)
        :type token: str
        :param body:
        :type body: CardholderNoteRequestModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CardholderNoteResponseModel, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token',
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_users_token_notes" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '201': "CardholderNoteResponseModel",
            '400': None,
            '401': None,
            '403': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/users/{token}/notes', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def put_users_token(self, token : Annotated[StrictStr, Field(..., description="User token")], body : Annotated[UserCardHolderUpdateModel, Field(..., description="User object")], **kwargs) -> CardHolderModel:  # noqa: E501
        """Updates a specific user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_users_token(token, body, async_req=True)
        >>> result = thread.get()

        :param token: User token (required)
        :type token: str
        :param body: User object (required)
        :type body: UserCardHolderUpdateModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CardHolderModel
        """
        kwargs['_return_http_data_only'] = True
        return self.put_users_token_with_http_info(token, body, **kwargs)  # noqa: E501

    @validate_arguments
    def put_users_token_with_http_info(self, token : Annotated[StrictStr, Field(..., description="User token")], body : Annotated[UserCardHolderUpdateModel, Field(..., description="User object")], **kwargs):  # noqa: E501
        """Updates a specific user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_users_token_with_http_info(token, body, async_req=True)
        >>> result = thread.get()

        :param token: User token (required)
        :type token: str
        :param body: User object (required)
        :type body: UserCardHolderUpdateModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CardHolderModel, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token',
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_users_token" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "CardHolderModel",
            '400': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/users/{token}', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def put_users_token_notes_notestoken(self, token : Annotated[StrictStr, Field(..., description="User token")], notes_token : Annotated[StrictStr, Field(..., description="Notes token")], body : Optional[CardholderNoteUpdateRequestModel] = None, **kwargs) -> CardholderNoteResponseModel:  # noqa: E501
        """Updates a specific note for a cardholder  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_users_token_notes_notestoken(token, notes_token, body, async_req=True)
        >>> result = thread.get()

        :param token: User token (required)
        :type token: str
        :param notes_token: Notes token (required)
        :type notes_token: str
        :param body:
        :type body: CardholderNoteUpdateRequestModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CardholderNoteResponseModel
        """
        kwargs['_return_http_data_only'] = True
        return self.put_users_token_notes_notestoken_with_http_info(token, notes_token, body, **kwargs)  # noqa: E501

    @validate_arguments
    def put_users_token_notes_notestoken_with_http_info(self, token : Annotated[StrictStr, Field(..., description="User token")], notes_token : Annotated[StrictStr, Field(..., description="Notes token")], body : Optional[CardholderNoteUpdateRequestModel] = None, **kwargs):  # noqa: E501
        """Updates a specific note for a cardholder  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_users_token_notes_notestoken_with_http_info(token, notes_token, body, async_req=True)
        >>> result = thread.get()

        :param token: User token (required)
        :type token: str
        :param notes_token: Notes token (required)
        :type notes_token: str
        :param body:
        :type body: CardholderNoteUpdateRequestModel
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CardholderNoteResponseModel, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token',
            'notes_token',
            'body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_users_token_notes_notestoken" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']

        if _params['notes_token']:
            _path_params['notes_token'] = _params['notes_token']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['body']:
            _body_params = _params['body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '201': "CardholderNoteResponseModel",
            '400': None,
            '401': None,
            '403': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/users/{token}/notes/{notes_token}', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))
